{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
{% for link in widget.list.link_set.all %}
<a style="position: absolute; top: 0; right: 0; border: 0;"  href="{{ link.web_address }}" >
    <img src="{{ link.image.file.url }}" alt="" />
</a>
{% endfor %}
{% endblock %}
