{% extends widget.get_base_template %}

{% load thumbnail %}

{% block content %}
<div class="row">
  {% for link in widget.list.link_set.all %}
  <div class="col-md-4 col-sm-6 {% if forloop.counter0|divisibleby:"4" %}no-margin{% endif %} thumb">
    {% include "widget/linkmenu/_icon.html" %}
  </div>
  {% endfor %}
</div>
{% endblock %}
