<div class="icon-box">
  <a href="{{ link.web_address }}" {% if link.target == '_blank' %}target=blank{% endif %} {% if link.target == '_modal' %}data-title="{{ widget.image.default_caption|default:'' }}" data-footer="{{ widget.image.description|default:'' }}" data-toggle="lightbox" rel="{{ widget.fe_identifier }}"{% endif %}>
    {% if link.image %}
    {% include 'widget/linkmenu/_icon.html' with link=item %}
    {% endif %}
    {% if link.translation.name %}
    <span>{{ link.translation.name }}</span>
    {% endif %}
  </a>
  {% if link.translation.description %}
  {{ link.translation.description|safe }}
  {% endif %}
</div>