{% load thumbnail %}
<div class="icon-box">
<a href="{{ link.web_address }}" class="{% if link.target == '_modal' %}modal ajax-modal{% endif %} {% if link.target == '_blank' %}blank{% endif %}">
    {% thumbnail link.image.file "250x48" format="PNG" as image %}
    <img src="{{ image.url }}" alt="" /><br />
    {% empty %}
    <span>{{ link }}</span>
    {% endthumbnail %}
</a>
<h3>{{ link }}</h3>
{{ link.translation.description|safe }}
</div>