{% extends widget.get_base_template %}
{% load divide %}

{% block content %}
{% block items %}
{% for row in widget.get_rows %}
  <div class="row">
  {% for item in row %}
    <div class="col-md-{{ 12|divide:widget.objects_per_row }}">
      {% include widget.get_item_template with link=item %}
    </div>
  {% endfor %}
  </div>
{% endfor %}
{% endblock %}
{% endblock %}

